@@ -58,11 +58,11 @@ App::Dochazka::REST - Dochazka REST server
 
 =head1 VERSION
 
-Version 0.501
+Version 0.502
 
 =cut
 
-our $VERSION = '0.501';
+our $VERSION = '0.502';
 
 
 =head2 Development status
@@ -1314,6 +1314,9 @@ sub reset_db {
     my $dbpass = $site->DOCHAZKA_DBPASS;
     $log->debug( "Entering " . __PACKAGE__ . "::reset_db to (re-)initialize database $dbname with superuser credentials $superuser / $superpass" );
 
+    # PGTZ *must* be set
+    $ENV{'PGTZ'} = $site->DOCHAZKA_TIMEZONE;
+
     my $conn = App::Dochazka::REST::ConnBank::get_arbitrary_dbix_conn(
         'postgres', $superuser, $superpass
     );
